import * as i18nService from "../service/i18n.service";
import { I18nInfoVO, I18nInfoPageVO } from "../service/i18n.service";

let { logger, ResponseUtils, optionalUtils: Optional, apiAssertUtils: ApiAssert } = require('@madex/ex-js-public');

/**
 * 分页查询列表
 * @param req
 * @param infoVO
 */
export const list = async (req: any, infoPageVO: I18nInfoPageVO) => {
    let func_name = "i18nCtrl.list";
    let cmd = req.path;
    try {
        infoPageVO.page = Optional.opt(infoPageVO, 'page', 1);
        infoPageVO.size = Optional.opt(infoPageVO, 'size', 50);
        infoPageVO.platform = Optional.opt(infoPageVO, 'platform', 1);
        infoPageVO.module = Optional.opt(infoPageVO, 'module', 1);
        infoPageVO.lang = Optional.opt(infoPageVO, 'lang', 'en');

        let res = await i18nService.list(infoPageVO);
        return ResponseUtils.success(cmd, res);
    }
    catch (e) {
        logger.error(`${func_name} error:${e}`);
        return ResponseUtils.error(func_name, cmd, e);
    }
};
/**
 * 添加国际化信息
 * @param req
 * @param infoVO
 */
export const add = async (req: any, infoVO: I18nInfoVO) => {
    let func_name = "i18nCtrl.add";
    let cmd = req.path;
    try {
        await preCheck(infoVO);
        let res = await i18nService.add(infoVO);
        return ResponseUtils.success(cmd, res);
    }
    catch (e) {
        logger.error(`${func_name} error:${e}`);
        return ResponseUtils.error(func_name, cmd, e);
    }
};
/**
 * 修改国际化信息
 * @param req
 * @param infoVO
 */
export const update = async (req: any, infoVO: I18nInfoVO) => {
    let func_name = "i18nCtrl.update";
    let cmd = req.path;
    try {
        ApiAssert.notNull('3000', infoVO.id);
        let res = await i18nService.update(infoVO);
        return ResponseUtils.success(cmd, res);
    }
    catch (e) {
        logger.error(`${func_name} error:${e}`);
        return ResponseUtils.error(func_name, cmd, e);
    }
};
/**
 * 删除国际化信息
 * @param req
 * @param infoVO
 */
export const del = async (req: any, infoVO: I18nInfoVO) => {
    let func_name = "i18nCtrl.del";
    let cmd = req.path;
    try {
        ApiAssert.notNull('3000', infoVO.id);
        let res = await i18nService.del(infoVO);
        return ResponseUtils.success(cmd, res);
    }
    catch (e) {
        logger.error(`${func_name} error:${e}`);
        return ResponseUtils.error(func_name, cmd, e);
    }
};


/**
 * 校验
 * @param infoVO
 */
async function preCheck(infoVO: I18nInfoVO) {
    if (![1, 2, 3, 4, 5].includes(infoVO.platform)) {
        throw '3000';
    }
    ApiAssert.notNull('3000', infoVO.module);
    ApiAssert.notNull('3000', infoVO.code);
    ApiAssert.notNull('3000', infoVO.lang);
    ApiAssert.notNull('3000', infoVO.content);
}